PushAction class

Inheritance

Constructors

PushAction(Map map)

Properties

app ↔ String?
action type app
getter/setter pairinherited
call ↔ String?
action type call
getter/setter pairinherited
clickedButton ↔ int?
action clicked
getter/setter pairinherited
destroy ↔ bool
action type boolean destroy
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
market ↔ String?
action type market
getter/setter pairinherited
noAction ↔ String?
action type no action
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
share ↔ String?
action type share
getter/setter pairinherited
topics ↔ List?
action type list of topics
getter/setter pairinherited
type ↔ Type?
action type
getter/setter pairinherited
url ↔ String?
action type url
getter/setter pairinherited
wallet ↔ String?
action type wallet
getter/setter pairinherited
webview ↔ String?
action type webview
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map
Convertion Model CoreAction to Map
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

ACTION → const String
String field name action